smartcard.Exceptions.ListReadersException

# ``smartcard`.`Exceptions`.`ListReadersException``

exception documentation

`class ListReadersException(SmartcardException):`

View In Hierarchy

Raised when smartcard readers cannot be listed.

Method | `__init__` | Undocumented

Inherited from `SmartcardException`:

Method | `__str__` | Undocumented
Instance Variable | `hresult` | Undocumented

def __init__(self, hresult):
overrides `smartcard.Exceptions.SmartcardException.__init__`

Undocumented